function [z1,z3]=periods(T,NL,filter) 
% Fourier analysis of the Laplace-Runge-Lenz vector 
% Usage:
% periods(T,NL,filter)
% where T and NL are returned by newton3d and
% 'filter' is one among 'hanning', 'hamming', 'bartlett', or 'none'

Month=27.3217;
Year=365.2570;
Saros=Year*18+11.3333;

if(nargin<3),
  filter='hanning';
end

disp(['Modulating the signal with with ' filter ' filter']);

N=max(size(NL));
f=NL(:,1)+i*NL(:,2);

switch filter
  case 'hanning'
    z1=fft((f-mean(f)).*hanning(N));
    z3=fft((NL(:,3)-mean(NL(:,3))).*hanning(N));
  case 'none'
    z1=fft((f-mean(f)));
    z3=fft((NL(:,3)-mean(NL(:,3))));
  case 'bartlett'
    z1=fft((f-mean(f)).*bartlett(N));
    z3=fft((NL(:,3)-mean(NL(:,3))).*bartlett(N));
  case 'hamming'
    z1=fft((f-mean(f)).*hamming(N));
    z3=fft((NL(:,3)-mean(NL(:,3))).*hamming(N));
  otherwise
    disp(['Unknown filter ' filter]);
    break
end



semilogy(abs(z1(1:N/4)));
hold on

p2=semilogy(abs(z3(1:N/4)),'g');

grid on

set(gca,'GridLineStyle',':','FontName','Courier','FontSize',14)
ylabel('spectral intensity')
xlabel('Fourier channel')

x1=max(T)/Month;
hold on
semilogy(x1, max(abs(z1))*2,'V','MarkerSize',10);
text(x1*1.2,max(abs(z1)),'Month^{-1}');
set(gca,'xTick',floor(2*x1*(1:10)))   
print -depsc spec1


figure

semilogy(abs(z1(1:x1)));
hold
semilogy(abs(z3(1:x1)),'g');
grid on

set(gca,'GridLineStyle',':','FontName','Courier','FontSize',14);

ylabel('spectral intensity')
xlabel('Fourier channel')

x2=max(T)/Year;
hold on

semilogy(x2, max(abs(z1))*2,'V','MarkerSize',10);
text(x2*1.2,max(abs(z1)),'Year^{-1}');
set(gca,'xTick',floor(x2*(1:10)))   
print -depsc spec2

figure

semilogy(abs(z1(1:x2)));
hold

semilogy(abs(z3(1:x2)),'g');

grid on

set(gca,'GridLineStyle',':','FontName','Courier','FontSize',14);
ylabel('spectral intensity')
xlabel('Fourier channel')

x3=max(T)/Saros;

semilogy(x3, max(abs(z1))*2,'V','MarkerSize',10);
text(x3*1.3,2*max(abs(z1)),'Saros^{-1}');
set(gca,'xTick',floor(2*x3*(1:20)));
print -depsc spec3


%---------------------

function h=hanning(n)			% Hanning window 

x=0:(n-1);
x=x';
h=1-cos(2*pi*x/n);
